@@ -12,12 +12,9 @@ It is designed to be used as follows::
 
     from __future__ import (absolute_import, division,
                             print_function, unicode_literals)
-    from future import *
-
-or explicitly as::
-
-    from future.builtins import (bytes, int, range, round, str, super,
-                                 ascii, chr, hex, input, oct, open,
+    from future.builtins import (bytes, dict, int, range, str,
+                                 ascii, chr, hex, input, next,
+                                 oct, open, pow, round, super,
                                  filter, map, zip)
 
 followed by predominantly standard, idiomatic Python 3 code that then runs
@@ -80,7 +77,7 @@ __license__ = 'MIT'
 __copyright__ = 'Copyright 2014 Python Charmers Pty Ltd'
 __ver_major__ = 0
 __ver_minor__ = 11
-__ver_patch__ = 2
+__ver_patch__ = 3
 __ver_sub__ = ''
 __version__ = "%d.%d.%d%s" % (__ver_major__, __ver_minor__,
                               __ver_patch__, __ver_sub__)
