@@ -32,6 +32,7 @@ class TestFuturizeSimple(CodeHandler):
         """
         self.convert_check(before, after)
 
+    @unittest.skip('--tobytes feature removed for now ...')
     def test_tobytes(self):
         """
         The --tobytes option converts all UNADORNED string literals 'abcd' to b'abcd'.
@@ -347,7 +348,7 @@ class TestFuturizeRenamedStdlib(CodeHandler):
         data = r.read()
         """
         after = """
-        import urllib.request
+        import urllib.request, urllib.parse, urllib.error
         
         URL = 'http://pypi.python.org/pypi/future/json'
         package_name = 'future'
