@@ -70,6 +70,7 @@ import numbers
 
 PY3 = sys.version_info[0] == 3
 PY2 = sys.version_info[0] == 2
+PY26 = sys.version_info[0:2] == (2, 6)
 PYPY = hasattr(sys, 'pypy_translation_info')
 
 
@@ -438,7 +439,7 @@ def isnewbytes(obj):
     """
     # TODO: generalize this so that it works with subclasses of newbytes
     # Import is here to avoid circular imports:
-    from future.builtins.backports.newbytes import newbytes
+    from future.builtins.types.newbytes import newbytes
     return type(obj) == newbytes
 
 
